cosmpy.protos.ibc.core.channel.v1 package — cosmpy documentation

# cosmpy.protos.ibc.core.channel.v1 package

## Submodules

## cosmpy.protos.ibc.core.channel.v1.channel_pb2 module

Generated protocol buffer code.

## cosmpy.protos.ibc.core.channel.v1.channel_pb2_grpc module

Client and server classes corresponding to protobuf-defined services.

## cosmpy.protos.ibc.core.channel.v1.genesis_pb2 module

Generated protocol buffer code.

## cosmpy.protos.ibc.core.channel.v1.genesis_pb2_grpc module

Client and server classes corresponding to protobuf-defined services.

## cosmpy.protos.ibc.core.channel.v1.query_pb2 module

Generated protocol buffer code.

## cosmpy.protos.ibc.core.channel.v1.query_pb2_grpc module

Client and server classes corresponding to protobuf-defined services.

class cosmpy.protos.ibc.core.channel.v1.query_pb2_grpc.Query

  Bases: `object`

  Query provides defines the gRPC querier service

  static Channel(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static ChannelClientState(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static ChannelConsensusState(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static Channels(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static ConnectionChannels(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static NextSequenceReceive(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static PacketAcknowledgement(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static PacketAcknowledgements(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static PacketCommitment(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static PacketCommitments(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static PacketReceipt(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static UnreceivedAcks(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static UnreceivedPackets(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)

class cosmpy.protos.ibc.core.channel.v1.query_pb2_grpc.QueryServicer

  Bases: `object`

  Query provides defines the gRPC querier service

  Channel(request, context)

    Channel queries an IBC Channel.

  ChannelClientState(request, context)

    ChannelClientState queries for the client state for the channel associated with the provided channel identifiers.

  ChannelConsensusState(request, context)

    ChannelConsensusState queries for the consensus state for the channel associated with the provided channel identifiers.

  Channels(request, context)

    Channels queries all the IBC channels of a chain.

  ConnectionChannels(request, context)

    ConnectionChannels queries all the channels associated with a connection end.

  NextSequenceReceive(request, context)

    NextSequenceReceive returns the next receive sequence for a given channel.

  PacketAcknowledgement(request, context)

    PacketAcknowledgement queries a stored packet acknowledgement hash.

  PacketAcknowledgements(request, context)

    PacketAcknowledgements returns all the packet acknowledgements associated with a channel.

  PacketCommitment(request, context)

    PacketCommitment queries a stored packet commitment hash.

  PacketCommitments(request, context)

    PacketCommitments returns all the packet commitments hashes associated with a channel.

  PacketReceipt(request, context)

    PacketReceipt queries if a given packet sequence has been received on the queried chain

  UnreceivedAcks(request, context)

    UnreceivedAcks returns all the unreceived IBC acknowledgements associated with a channel and sequences.

  UnreceivedPackets(request, context)

    UnreceivedPackets returns all the unreceived IBC packets associated with a channel and sequences.

class cosmpy.protos.ibc.core.channel.v1.query_pb2_grpc.QueryStub(channel)

  Bases: `object`

  Query provides defines the gRPC querier service

cosmpy.protos.ibc.core.channel.v1.query_pb2_grpc.add_QueryServicer_to_server(servicer, server)

## cosmpy.protos.ibc.core.channel.v1.tx_pb2 module

Generated protocol buffer code.

## cosmpy.protos.ibc.core.channel.v1.tx_pb2_grpc module

Client and server classes corresponding to protobuf-defined services.

class cosmpy.protos.ibc.core.channel.v1.tx_pb2_grpc.Msg

  Bases: `object`

  Msg defines the ibc/channel Msg service.

  static Acknowledgement(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static ChannelCloseConfirm(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static ChannelCloseInit(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static ChannelOpenAck(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static ChannelOpenConfirm(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static ChannelOpenInit(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static ChannelOpenTry(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static RecvPacket(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static Timeout(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static TimeoutOnClose(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)

class cosmpy.protos.ibc.core.channel.v1.tx_pb2_grpc.MsgServicer

  Bases: `object`

  Msg defines the ibc/channel Msg service.

  Acknowledgement(request, context)

    Acknowledgement defines a rpc handler method for MsgAcknowledgement.

  ChannelCloseConfirm(request, context)

    ChannelCloseConfirm defines a rpc handler method for MsgChannelCloseConfirm.

  ChannelCloseInit(request, context)

    ChannelCloseInit defines a rpc handler method for MsgChannelCloseInit.

  ChannelOpenAck(request, context)

    ChannelOpenAck defines a rpc handler method for MsgChannelOpenAck.

  ChannelOpenConfirm(request, context)

    ChannelOpenConfirm defines a rpc handler method for MsgChannelOpenConfirm.

  ChannelOpenInit(request, context)

    ChannelOpenInit defines a rpc handler method for MsgChannelOpenInit.

  ChannelOpenTry(request, context)

    ChannelOpenTry defines a rpc handler method for MsgChannelOpenTry.

  RecvPacket(request, context)

    RecvPacket defines a rpc handler method for MsgRecvPacket.

  Timeout(request, context)

    Timeout defines a rpc handler method for MsgTimeout.

  TimeoutOnClose(request, context)

    TimeoutOnClose defines a rpc handler method for MsgTimeoutOnClose.

class cosmpy.protos.ibc.core.channel.v1.tx_pb2_grpc.MsgStub(channel)

  Bases: `object`

  Msg defines the ibc/channel Msg service.

cosmpy.protos.ibc.core.channel.v1.tx_pb2_grpc.add_MsgServicer_to_server(servicer, server)

## Module contents